@@ -140,7 +140,7 @@ class StateSpace:
             return ds
 
 class PoolEnvCon(gym.Env, gym_utils.EzPickle):
-    def __init__(self, num_balls=2, visualize=False, single = False):
+    def __init__(self, num_balls=2, visualize=False, single = True):
         self.num_balls = num_balls
         self.visualize = visualize
         self.singlePlayer = single
